@@ -11,6 +11,7 @@
 #' @param weighted Logical indicating whether weighted efficiency should be
 #'   calculated (default: \code{FALSE})
 #' @export
+#' @importFrom Matrix rowSums
 #'
 #' @return A numeric vector of length equal to the vertex count of \emph{g}
 #'
@@ -36,13 +37,9 @@ vulnerability <- function(g, use.parallel=TRUE, weighted=FALSE) {
   } else {
     E.global <- graph_attr(g, g.attr)
   }
-  if (!'degree' %in% vertex_attr_names(g)) {
-    degs <- degree(g)
-  } else {
-    degs <- V(g)$degree
-  }
-  vuln <- rep(0, length(degs))
-  nodes <- which(degs > 0)
+
+  vuln <- rep(0, nrow(A))
+  nodes <- which(rowSums((A > 0) + 0) != 0)
   if (isTRUE(use.parallel)) {
     vuln[nodes] <- foreach(i=nodes, .combine='c') %dopar% {
       g.tmp <- graph_from_adjacency_matrix(A[-i, -i], mode='undirected', weighted=weighted)
